@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 #!/usr/bin/python3
 
 # Persistence-of-vision (POV) example for Adafruit DotStar RGB LED strip.
@@ -38,8 +41,7 @@ WIDTH = IMG.size[0]
 HEIGHT = IMG.size[1]
 print("%dx%d pixels" % IMG.size)
 
-if HEIGHT > NUMPIXELS:
-    HEIGHT = NUMPIXELS
+HEIGHT = min(HEIGHT, NUMPIXELS)
 
 # Calculate gamma correction table, makes mid-range colors look 'right':
 GAMMA = bytearray(256)
